======================
Django Very Simple API
======================

Very simple API is a Django app to provide simple queryset serialization of any model.
In additional to serialization, it also provides a framework for handling simple API calls.

Detailed information to come...
